

import java.io.File;
import java.io.FileInputStream;
import java.util.HashMap;
import java.util.Properties;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.InitialContext;

/**
 * A simple program to send a message to queue
 */
public class MySender {
	public static void main(final String[] args) {
		try {
			new MySender().runExample();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public boolean runExample() throws Exception {
		final int numMessages = 1;
		Connection connection = null;
		InitialContext initialContext = null;

		try {
			// Step 1. Get an initial context for looking up JNDI from the
			// server #1
			initialContext = getContext();

			// Step 2. Look up the JMS resources from JNDI
			Queue queue = (Queue) initialContext.lookup("/queue/requestQ");
			Queue mdbQueue = (Queue) initialContext.lookup("/queue/mdbRequestQ");

			ConnectionFactory connectionFactory = (ConnectionFactory) initialContext
					.lookup("/XAConnectionFactory");

			// Step 3. Create a JMS Connection
			connection = connectionFactory.createConnection();

			// Step 4. Create a *non-transacted* JMS Session with client
			// acknowledgment
			Session session = connection.createSession(false,
					Session.AUTO_ACKNOWLEDGE);

			// Step 5. Start the connection to ensure delivery occurs
			connection.start();

			// Step 6. Create a JMS MessageProducer and a MessageConsumer
			MessageProducer producer = session.createProducer(queue);
			MessageProducer mdbProducer = session.createProducer(mdbQueue);
			
			// Step 7. Send some messages to server #1, the live server
			for (int i = 0; i < numMessages; i++) {
				TextMessage message = session
						.createTextMessage("This is text message " + i);
				producer.send(message);
				mdbProducer.send(message);
				System.out.println("Sent message: " + message.getText());
			}

			return true;
		} finally {
			// Step 13. Be sure to close our resources!

			if (connection != null) {
				connection.close();
			}

			if (initialContext != null) {
				initialContext.close();
			}
		}
	}

	
	protected InitialContext getContext() throws Exception {
		Properties props = new Properties();

		HashMap map = new HashMap();
		map.put("java.naming.factory.initial",
				"org.jnp.interfaces.NamingContextFactory");

		map.put("java.naming.provider.url",
				"nodeq1:1099");

		map.put("java.naming.factory.url.pkgs",
				"org.jboss.naming:org.jnp.interfaces");
		props.putAll(map);
		return new InitialContext(props);
	}

}